@@ -16,10 +16,10 @@ has [qw(
     gmarkname    
 )];
 has member => sub{[]};
-has displayname => sub{
+sub displayname {
     my $self = shift;
     return defined $self->gmarkname?$self->gmarkname:$self->gname;
-};
+}
 sub new {
     my $class = shift;
     my $self ;
@@ -61,7 +61,7 @@ sub add_group_member{
     my $self = shift;   
     my $member = shift;
     my $nocheck = shift;
-    $self->die("不支持的数据类型") if ref $member ne "Mojo::Webqq::Group::Member";
+    $self->{_client}->die("不支持的数据类型") if ref $member ne "Mojo::Webqq::Group::Member";
     if($nocheck){
         push @{$self->member},$member;
         return $self;
@@ -76,9 +76,22 @@ sub add_group_member{
     return $self;
 }   
 
+sub remove_group_member{
+    my $self = shift;
+    my $member = shift;
+    $self->{_client}->die("不支持的数据类型") if ref $member ne "Mojo::Webqq::Group::Member";
+    for(my $i=0;$i<@{$self->member};$i++){
+        if($self->member->[$i]->id eq $member->id){
+            splice @{$self->member},$i,1;
+            return 1;
+        }
+    }
+    return;
+}
+
 sub is_empty{
     my $self = shift;
-    return !(ref($self->member eq "ARRAY")?0+@{$self->member}:0);
+    return !(ref($self->member) eq "ARRAY"?0+@{$self->member}:0);
 }
 
 sub update{
@@ -87,15 +100,25 @@ sub update{
     for(keys %$self){
         if($_ eq "member" and ref $hash->{member} eq "ARRAY"){
             next if not @{$hash->{member}};
-            my @member = map { $self->{_client}->new_group_member->new($_) } @{$hash->{member}};
+            my @member = map {ref($_ eq "Mojo::Webqq::Group::Member")?$_:$self->{_client}->new_group_member->new($_)} @{$hash->{member}};
             if( $self->is_empty() ){
                 $self->member(\@member);
             }
             else{
-                my($new_members,$lost_members)=$self->array_diff($self->member, \@member,sub{$_[0]->id});
-                $self->{_client}->emit(new_group_member=>$_) for @{$new_members};
-                $self->{_client}->emit(lose_group_member=>$_) for @{$lost_members};
-                $self->member(\@member);
+                my($new_members,$lost_members,$sames)=$self->{_client}->array_diff($self->member, \@member,sub{$_[0]->id});
+                for(@{$new_members}){
+                    $self->add_group_member($_);
+                    $self->{_client}->emit(new_group_member=>$_);
+                }
+                for(@{$lost_members}){
+                    $self->remove_group_member($_);
+                    $self->{_client}->emit(lose_group_member=>$_);
+                }
+                for(@{$sames}){
+                    my($old_member,$new_member) = ($_->[0],$_->[1]);
+                    $old_member->update($new_member); 
+                }
+                #$self->member(\@member);
             }
         }
         else{
