@@ -1,4 +1,3 @@
-use Encode;
 sub Mojo::Webqq::Message::_send_discuss_message {
     my $self = shift;
     my $msg = shift;
@@ -32,7 +31,22 @@ sub Mojo::Webqq::Message::_send_discuss_message {
         Referer => 'http://d.web2.qq.com/proxy.html?v=20130916001&callback=1&id=2',
         json    => 1,
     }; 
-    my $content = [decode("utf8",$msg->{content}),"",[]];
+    use Encode;
+    my @content  = map {
+        if($_->{type} eq "txt"){decode "utf8",$_->{content}}
+        elsif($_->{type} eq "face"){["face",0+$_->{id}]}
+    } @{$msg->raw_content};
+    #for(my $i=0;$i<@content;$i++){
+    #    if(ref $content[$i] eq "ARRAY"){
+    #        if(ref $content[$i] eq "ARRAY"){
+    #            splice @content,$i+1,0," ";
+    #        }
+    #        else{
+    #            $content[$i+1] = " " . $content[$i+1];
+    #        }
+    #    }
+    #}
+    my $content = [@content,["font",{name=>decode("utf8","宋体"),size=>10,style=>[0,0,0],color=>"000000"}]];
     my %s = (
         did         => $msg->discuss_id,
         face        => $self->user->face || 591,
